@@ -1,5 +1,5 @@
 /* example3.c --- Example ToASCII() code showing how to use Libidn.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -39,7 +39,7 @@
  */
 
 int
-main (int argc, char *argv[])
+main (void)
 {
   char buf[BUFSIZ];
   char *p;
